@@ -14,19 +14,46 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
-#ifndef _EDITDEFAULTS_H_
-#define _EDITDEFAULTS_H_
+#ifndef _KU_EDITDEFAULTS_H_
+#define _KU_EDITDEFAULTS_H_
 
+#include <qmemarray.h>
 #include <kconfigdialog.h>
+#include <kprogress.h>
+#include <kabc/ldif.h>
+#include "ldapsamba.h"
+
+class LdapSamba;
+namespace KABC { class LdapConfigWidget; }
+namespace KIO { class Job; }
+
+typedef struct SambaDomain {
+  QString name;
+  QString sid;
+  uint ridbase;
+};
 
 class editDefaults : public KConfigDialog {
   Q_OBJECT
 public:
   editDefaults( KConfigSkeleton *config, QWidget* parent, const char * name = 0 );
+private:
+  KProgressDialog *mProg;
+  LdapSamba *page3c;
+  KABC::LdapConfigWidget *ldconf;
+  KABC::LDIF mLdif;
+  bool mCancelled;
+  QString mErrorMsg;
+  QValueList<SambaDomain> mResult;
+  SambaDomain mDomain;
+private slots:
+  void slotQueryClicked();
+  void loadData( KIO::Job*, const QByteArray& d );
+  void loadResult( KIO::Job* job);
 };
 
-#endif // _EDITDEFAULTS_H_
+#endif // _KU_EDITDEFAULTS_H_
